# Copyrights 2001-2015 by [Mark Overmeer].
#  For other contributors see ChangeLog.
# See the manual pages for details on the licensing terms.
# Pod stripped from pm file by OODoc 2.01.

package MailBox::Test::51folder::Definition;
use vars '$VERSION';
$VERSION = '2.118';


sub name     {"Mail::Box; general folder handling"}
sub critical {1}
sub skip     { undef }

1;
